import * as React from 'react';
export declare type DropdownMenuProps = {
    /** React Children. Is used to render Items, Header, etc.  */
    children?: React.ReactNode;
    /** Allows providing a custom class name to the DIV element that surrounds the text */
    className?: string;
    /** Enables closing the dropdown menu when clicking outside */
    closeOnClickAnywhere?: boolean;
    /** Default open value */
    defaultValue?: boolean;
    /** Whether it should be disabled (no clicks will work) or not */
    disabled?: boolean;
    /** Callback triggered whenever the state is changed */
    onChange?: () => void;
    /** Callback triggered whenever the dropdown is closed */
    onClose?: () => void;
    /** Callback triggered whenever the dropdown is opened */
    onOpen?: () => void;
    /** Callback triggered when the dropdown is going to close (before onClose) */
    onRequestToChange?: () => void;
    /** Whether the dropdown is open or not */
    open?: boolean;
} & React.ComponentPropsWithoutRef<'div'>;
declare type TState = {
    open: boolean;
    width: number | null | undefined;
};
declare class DropdownMenu extends React.PureComponent<DropdownMenuProps, TState> {
    dropdownRef: React.RefObject<HTMLDivElement>;
    static defaultProps: {
        disabled: boolean;
        open: null;
        defaultValue: boolean;
    };
    controlledComponent: boolean;
    constructor(props: DropdownMenuProps);
    componentDidMount(): void;
    componentDidUpdate(): void;
    componentWillUnmount(): void;
    get open(): boolean;
    get onToggleCallback(): (() => void) | undefined;
    dropdownCurrentRef: () => any;
    _handleClickOutside: (event: MouseEvent) => void;
    handleRequestToChange: () => void;
    handleOpen: () => void;
    handleClose: () => void;
    handleToggle: () => void;
    render(): React.ReactNode;
}
export default DropdownMenu;
